@@ -6,10 +6,11 @@ use utf8;
 BEGIN
 {
 use strict;
+use warnings;
 use vars qw($VERSION @EXPORT_OK %TigrignaEquivalence %TigrignaClassEquivalence);
 
 
-	$VERSION = "0.05";
+	$VERSION = "0.17";
 	
 	@EXPORT_OK = qw(%TigrignaEquivalence %TigrignaClassEquivalence);
 
@@ -202,6 +203,7 @@ $_ = ($#_) ? $_[1] : $_[0];
 
 __END__
 
+=encoding utf8
 
 =head1 NAME
 
@@ -272,4 +274,8 @@ None presently known.
 
 Daniel Yacob,  L<dyacob@cpan.org|mailto:dyacob@cpan.org>
 
+=head1 LICENSE AND COPYRIGHT
+
+Copyright (c) 2003-2025, Daniel Yacob C<< <dyacob@cpan.org> >>. All rights reserved.
+
 =cut
